@@ -1,3 +1,5 @@
+#!/usr/bin/env python3
+
 import argparse
 import os
 import yaml
@@ -16,18 +18,15 @@ def main():
     cwd = os.getcwd()
     print(cwd)
     print(__file__)
+    print(os.path.dirname(__file__))
 
     parser = argparse.ArgumentParser('recaud')
-    parser.add_argument('--config', '-c')
+    parser.add_argument('config')
     parser.add_argument('--output', '-o')
 
     args = parser.parse_args()
 
-    if args.config:
-        config_file = args.config
-    else:
-        config_file = os.path.join(os.path.dirname(__file__), '..', 'config.yml')
-
+    config_file = args.config
     config = load_yaml(config_file)
 
     if args.output:
@@ -36,9 +35,6 @@ def main():
         date_str = datetime.now(timezone.utc).strftime('%Y-%m-%d-%H:%M:%S')
         output_file = 'alog_' + date_str + '.' + str(config['ext'])
 
-    ##############################################################################
-    # building and running command
-
     command = 'ffmpeg -f alsa -ar ' + str(config['ar']) + ' -ac ' + str(config['ac']) + ' -i ' + str(config['mic']) + ' ' + output_file
 
     os.system(command)
